@@ -1,3 +1,4 @@
+from symbl.utils.Logger import Log
 from symbl.utils.Threads import Thread
 
 def wrap_keyboard_interrupt(function):
@@ -5,9 +6,10 @@ def wrap_keyboard_interrupt(function):
         try:
             function(*args, **kw)
         except KeyboardInterrupt:
-            print("Closing all connections")
+            Log.getInstance().info("Closing all connections")
             self = args[0]
-            self.connection.sock.close()
+            if hasattr(self, "connection"):
+                self.connection.sock.close()
             Thread.getInstance().stop_all_threads()
     
     return wrapper
\ No newline at end of file
